@@ -1044,6 +1044,10 @@ _GI_TEST_EXTERN
 RegressTestFundamentalSubObject *
 regress_test_fundamental_sub_object_new (const char *data);
 
+_GI_TEST_EXTERN
+RegressTestFundamentalObject *
+regress_test_create_fundamental_hidden_class_instance (void);
+
 /* callback */
 typedef void (*RegressTestSimpleCallback) (void);
 typedef void RegressTestNoPtrCallback (void);
@@ -1449,6 +1453,19 @@ typedef struct {
   };
 } RegressAnAnonymousUnion;
 
+typedef struct {
+  int x;
+
+  union {
+    struct {
+      RegressLikeGnomeKeyringPasswordSchema *a;
+      RegressLikeXklConfigItem *b;
+    };
+
+    guint padding[4];
+  };
+} RegressAnonymousUnionAndStruct;
+
 GVariant *
 regress_get_variant (void);
 
